@@ -41,6 +41,40 @@ def generate_2D_polar_grid(
         r_range=None, r_grid=None, dr=None, nr=None,
         theta_range=None, theta_grid=None, dtheta=None, ntheta=None):
 
+    '''
+    Generate a 2D polar grid.
+
+    Parameters
+    ----------
+    r_range : tuple
+        Range of the radial coordinate.
+    r_grid : np.ndarray
+        Grid of the radial coordinate.
+    dr : float
+        Step of the radial coordinate.
+    nr : int
+        Number of points of the radial coordinate.
+    theta_range : tuple
+        Range of the angular coordinate.
+    theta_grid : np.ndarray
+        Grid of the angular coordinate.
+    dtheta : float
+        Step of the angular coordinate.
+    ntheta : int
+        Number of points of the angular coordinate.
+
+    Returns
+    -------
+    a1 : np.ndarray
+        First normalized coordinate.
+    a2 : np.ndarray
+        Second normalized coordinate.
+    r_all : np.ndarray
+        Radial coordinate.
+    theta_all : np.ndarray
+        Angular coordinate.
+    '''
+
     _r_grid = _configure_grid('r', r_grid, dr, r_range, nr)
     _theta_grid = _configure_grid('theta', theta_grid, dtheta,
                                   theta_range, ntheta)
@@ -59,6 +93,29 @@ def generate_2D_polar_grid(
 def generate_2D_uniform_circular_sector(num_particles, r_range=(0, 1),
                                         theta_range=(0, 2*np.pi)):
 
+    '''
+    Generate a 2D uniform circular sector.
+
+    Parameters
+    ----------
+    num_particles : int
+        Number of particles to be generated.
+    r_range : tuple
+        Range of the radial coordinate.
+    theta_range : tuple
+        Range of the angular coordinate.
+
+    Returns
+    -------
+    a1 : np.ndarray
+        First normalized coordinate.
+    a2 : np.ndarray
+        Second normalized coordinate.
+    r_all : np.ndarray
+        Radial coordinate.
+    theta_all : np.ndarray
+        Angular coordinate.
+    '''
 
     # CDF(r) = (r^2 - r0^2)/(r1^2 - r0^2)
     # InvCDF(u) = sqrt(r0^2 + u * (r1^2 -r0^2))
